@@ -1,7 +1,8 @@
 package App::PerlWatcher::UI::Gtk2::StatusesTreeView;
 {
-  $App::PerlWatcher::UI::Gtk2::StatusesTreeView::VERSION = '0.07_1';
+  $App::PerlWatcher::UI::Gtk2::StatusesTreeView::VERSION = '0.07_2';
 }
+# ABSTRACT: Widget for displaying statuses in tree-like presentation
 
 use 5.12.0;
 use strict;
@@ -224,3 +225,28 @@ sub _constuct_timestamp_column {
 }
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+App::PerlWatcher::UI::Gtk2::StatusesTreeView - Widget for displaying statuses in tree-like presentation
+
+=head1 VERSION
+
+version 0.07_2
+
+=head1 AUTHOR
+
+Ivan Baidakou <dmol@gmx.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Ivan Baidakou.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
