@@ -1,7 +1,8 @@
 package App::PerlWatcher::UI::Gtk2::Utils;
 {
-  $App::PerlWatcher::UI::Gtk2::Utils::VERSION = '0.07_1';
+  $App::PerlWatcher::UI::Gtk2::Utils::VERSION = '0.07_2';
 }
+# ABSTRACT: Helping functions for Gtk2 app
 
 use 5.12.0;
 use strict;
@@ -43,3 +44,28 @@ sub get_icon {
     my $pixbuff = Gtk2::Gdk::Pixbuf->new_from_file_at_scale($filename, @icon_size, 1);
     return $pixbuff;
 }
+
+__END__
+
+=pod
+
+=head1 NAME
+
+App::PerlWatcher::UI::Gtk2::Utils - Helping functions for Gtk2 app
+
+=head1 VERSION
+
+version 0.07_2
+
+=head1 AUTHOR
+
+Ivan Baidakou <dmol@gmx.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Ivan Baidakou.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
